antares.apps.notifications package — Antares 0.0.2 documentation

# antares.apps.notifications package

## Subpackages

- antares.apps.notifications.console package
  - Submodules
  - antares.apps.notifications.console.notifications_console module
  - Module contents
- antares.apps.notifications.manager package
  - Submodules
  - antares.apps.notifications.manager.notification_manager module
  - Module contents
- antares.apps.notifications.migrations package
  - Submodules
  - antares.apps.notifications.migrations.0001_initial module
  - antares.apps.notifications.migrations.0002_auto_20180624_1759 module
  - Module contents
- antares.apps.notifications.models package
  - Submodules
  - antares.apps.notifications.models.notification_record module
  - antares.apps.notifications.models.notification_rule module
  - Module contents
- antares.apps.notifications.templatetags package
  - Submodules
  - antares.apps.notifications.templatetags.notification_tags module
  - Module contents
- antares.apps.notifications.tests package
  - Module contents

## Submodules

## antares.apps.notifications.admin module

## antares.apps.notifications.apps module

class `antares.apps.notifications.apps.` `NotificationsConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'notifications'

## antares.apps.notifications.constants module

## Module contents